@@ -198,13 +198,15 @@ def Trajectory(data,bodyPartTraj,bodyPartBox = None, **kwargs):
         ax.plot([esquerda,direita]  , [cima,cima],"k")
         ax.plot([direita,direita]   , [cima,baixo],"k")
         ax.plot([direita,esquerda]  , [baixo,baixo],"k")
-        ax.tick_params(axis='both', which='major', labelsize=fontsize)
+        ax.tick_params(axis='both', which='major', labelsize=fontsize*0.8)
         ax.set_title(figureTitle, fontsize=fontsize)
+        ax.set_xlabel("X (px)", fontsize = fontsize)
+        ax.set_ylabel("Y (px)", fontsize = fontsize)
 
         divider = make_axes_locatable(ax)
         cax = divider.append_axes('right',size='5%', pad=0.05)
         cb = fig.colorbar(plot,cax=cax)
-        cb.ax.tick_params(labelsize=fontsize)
+        cb.ax.tick_params(labelsize=fontsize*0.8)
         cb.set_label(label='Time (s)', fontsize=fontsize)
 
         if invertY == True:
